#include "display.h"
#include "window.h"
#include "window_private.h"

using namespace std;

namespace Msp {
namespace Graphics {

WindowOptions::WindowOptions():
	width(640),
	height(480),
	fullscreen(false),
	resizable(false)
{ }


Window::Window(Display &dpy, unsigned w, unsigned h, bool fs):
	display(dpy)
{
	options.width = w;
	options.height = h;
	options.fullscreen = fs;

	init();
}

Window::Window(Display &dpy, const WindowOptions &opts):
	display(dpy),
	options(opts)
{
	init();
}

void Window::init()
{
	visible = false;
	kbd_autorepeat = true;
	resizing = false;
	priv = new Private;

	platform_init();

	display.add_window(*this);
	display.check_error();
}

Window::~Window()
{
	platform_cleanup();

	display.remove_window(*this);

	if(options.fullscreen && visible)
		display.restore_mode();

	delete priv;
}

void Window::reconfigure(const WindowOptions &opts)
{
	bool fullscreen_changed = (opts.fullscreen!=options.fullscreen);
	if(opts.width!=options.width || opts.height!=options.height)
		resizing = true;

	if(visible)
	{
		if(opts.fullscreen)
			display.set_mode(VideoMode(opts.width, opts.height));
		else if(fullscreen_changed)
			display.restore_mode();
	}

	options = opts;
	platform_reconfigure(fullscreen_changed);
}

void Window::set_keyboard_autorepeat(bool r)
{
	kbd_autorepeat = r;
}

void Window::show()
{
	platform_show();
	visible = true;

	if(options.fullscreen)
	{
		display.set_mode(VideoMode(options.width, options.height), true);
		warp_pointer(options.width/2, options.height/2);
	}
}

void Window::hide()
{
	platform_hide();
	visible = false;

	if(options.fullscreen)
		display.restore_mode();
}

} // namespace Graphics
} // namespace Msp
