#ifndef MSP_INPUT_BINARYCONTROL_H_
#define MSP_INPUT_BINARYCONTROL_H_

#include "control.h"

namespace Msp {
namespace Input {

/**
A control with two possible states.  Button state is mapped directly.  An axis
is considered to be active when its value is above a threshold (0.5 by
default).
*/
class BinaryControl: public Control
{
public:
	sigc::signal<void> signal_press;
	sigc::signal<void> signal_release;

private:
	bool state;
	float threshold;

public:
	BinaryControl();
	BinaryControl(const ControlSource &);
	BinaryControl(Device &, ControlSrcType, unsigned);
	virtual ~BinaryControl();

	/** Sets the threshold between states for axis sources.  No effect on button
	sources */
	void set_threshold(float);

	bool get_state() const { return state; }

private:
	virtual void on_press();
	virtual void on_release();
	virtual void on_motion(float, float);
};

} // namespace Input
} // namespace Msp

#endif
